Enum PulsePolarity
pub enum PulsePolarity {
High,
Low,
Both,
}Expand description
Pulse polarity for PulseDuration.
Variants
High
Only consider “high” pulses (i.e., when the boolean value is true).
The duration will be output on the falling edge.
Low
Only consider “low” pulses (i.e., when the boolean value is false).
The duration will be output on the rising edge.
Both
Consider both “high” and “low” pulses.
The duration will be output every time the boolean value changes.