Struct PulseDuration
pub struct PulseDuration {
keep_negative: bool,
polarity: PulsePolarity,
last: Option<(DateTime<Utc>, bool)>,
}Expand description
Mutable step that outputs the duration of a pulse.
This step operates on boolean values and will explicitly cast non-boolean values to boolean using whalesong::Value::cast_boolean_value.
A pulse is a contiguous period of time where the boolean value remains the same. You can explicitly select whether you only want to consider the “high”, “low”, or both pulses.
To better illustrate the concept of a pulse, here’s an illustration:
true /---------\ /---------\
| | | |
false __/ \_________/ |
^ ^ ^ ^
t0 t1 t2 t3There are three pulses in the above example:
Fields
keep_negative: boolpolarity: PulsePolaritylast: Option<(DateTime<Utc>, bool)>Implementations
impl PulseDuration
impl PulseDuration
pub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance.
pub const fn with_keep_negative(self, keep_negative: bool) -> Self
pub const fn with_keep_negative(self, keep_negative: bool) -> Self
Configures whether to emit negative durations.
By default, negative durations are dropped.
pub const fn with_polarity(self, polarity: PulsePolarity) -> Self
pub const fn with_polarity(self, polarity: PulsePolarity) -> Self
Configures the pulse polarity.
By default, only “high” pulses are considered.